@@ -8,7 +8,7 @@ use strict;
 use warnings;
 
 our $AUTHORITY = 'cpan:MAROS';
-our $VERSION = 1.37;
+our $VERSION = 1.37_01;
 
 use MooseX::App::Meta::Role::Attribute::Option;
 use MooseX::App::Exporter qw(app_usage app_description app_base app_fuzzy app_strict app_prefer_commandline app_permute option parameter);
@@ -17,7 +17,7 @@ use Moose::Exporter;
 use Scalar::Util qw(blessed);
 
 my ($IMPORT,$UNIMPORT,$INIT_META) = Moose::Exporter->build_import_methods(
-    with_meta           => [ qw(app_usage app_description app_namespace app_base app_fuzzy app_command_name app_command_register app_strict app_prefer_commandline option parameter app_permute) ],
+    with_meta           => [ qw(app_usage app_description app_namespace app_exclude app_base app_fuzzy app_command_name app_command_register app_strict app_prefer_commandline option parameter app_permute) ],
     also                => [ 'Moose' ],
     as_is               => [ 'new_with_command' ],
     install             => [ 'unimport','init_meta' ],
@@ -73,6 +73,11 @@ sub app_namespace(@) {
     return $meta->app_namespace( \@namespaces );
 }
 
+sub app_exclude(@) {
+    my ( $meta, @namespaces ) = @_;
+    return $meta->app_exclude( \@namespaces );
+}
+
 sub new_with_command {
     my ($class,@args) = @_;
 
@@ -132,7 +137,7 @@ sub new_with_command {
         );
     # Looks like a command
     } else {
-        my $return = $meta->command_find($first_argv);
+        my $return = $meta->command_find();
 
         # Nothing found
         if (blessed $return
@@ -180,7 +185,8 @@ In your base class:
   ); # not exposed
 
 Write multiple command classes (If you have only a single command class
-you should use L<MooseX::App::Simple> instead)
+you should use L<MooseX::App::Simple> instead). Packackes in the namespace may be
+deeply nested.
 
   package MyApp::SomeCommand;
   use MooseX::App::Command; # important (also imports Moose)
@@ -270,6 +276,7 @@ the user for additional parameters see L<MooseX::App::Plugin::Term>)
 
 =item * Provide helpful error messages if user input cannot be validated
 (either missing or wrong attributes or Moose type constraints not satisfied)
+or if the user requests help.
 
 =back
 
@@ -425,6 +432,13 @@ multiple extra namespaces.
 If app_namespace is called with no arguments then autoloading of command
 classes will be disabled entirely.
 
+=head2 app_exclude
+
+ app_exclude 'MyApp::Commands::Roles','MyApp::Commands::Utils';
+
+A sub namespace included via app_namespace (or the default behaviour) can
+be excluded using app_exclude.
+
 =head2 app_command_name
 
  app_command_name {
@@ -661,7 +675,7 @@ list of open wishlist issues for ideas.
 
 =head1 COPYRIGHT
 
-MooseX::App is Copyright (c) 2012-16 Maroš Kollár.
+MooseX::App is Copyright (c) 2012-17 Maroš Kollár.
 
 This library is free software and may be distributed under the same terms as
 perl itself. The full text of the licence can be found in the LICENCE file
